@@ -25,51 +25,49 @@
  * Description:		An application for analysing MCMC trace files.
  * @author			Andrew Rambaut
  * @author			Alexei Drummond
- * @version			$Id: FigTreeApplication.java 260 2015-03-05 11:24:23Z rambaut $
+ * @version			$Id$
  */
 
 package figtree.application;
 
-import figtree.application.preferences.*;
+import com.itextpdf.text.DocumentException;
+import figtree.application.preferences.AppearancePreferencesSection;
+import figtree.application.preferences.FontsPreferencesSection;
 import figtree.treeviewer.ExtendedTreeViewer;
-import jam.framework.*;
 import jam.controlpalettes.BasicControlPalette;
 import jam.controlpalettes.ControlPalette;
+import jam.framework.*;
 import jam.mac.Utils;
-
-import java.awt.*;
-import java.awt.image.BufferedImage;
-import java.io.*;
-import java.net.URL;
-import java.util.*;
-import java.util.List;
-
 import jebl.evolution.io.ImportException;
 import jebl.evolution.io.NewickImporter;
 import jebl.evolution.trees.Tree;
 
-import javax.imageio.ImageIO;
 import javax.swing.*;
-
-import ch.randelshofer.quaqua.QuaquaManager;
+import java.awt.*;
+import java.io.*;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.net.URL;
+import java.util.*;
+import java.util.List;
 
 /**
  * Application class for FigTree including main() method for invoking it.
  * Uses JAM Application classes to create a MultiDoc Application.
  *
  * @author Andrew Rambaut
- * @version $Id: FigTreeApplication.java 260 2015-03-05 11:24:23Z rambaut $
+ * @version $Id$
  *
- * $HeadURL: http://figtree.googlecode.com/svn/trunk/src/figtree/application/FigTreeApplication.java $
+ * $HeadURL$
  *
- * $LastChangedBy: rambaut $
- * $LastChangedDate: 2015-03-05 12:24:23 +0100 (jeu. 05 mars 2015) $
- * $LastChangedRevision: 260 $
+ * $LastChangedBy$
+ * $LastChangedDate$
+ * $LastChangedRevision$
  */
 public class FigTreeApplication extends MultiDocApplication {
 
-    public static final String VERSION = "1.4.3";
-    public static final String DATES = "2006-2015";
+    public static final String VERSION = "1.4.4";
+    public static final String DATES = "2006-2018";
 
     public static FigTreeApplication application;
 
@@ -164,34 +162,10 @@ public class FigTreeApplication extends MultiDocApplication {
 
             GraphicFormat format = null;
             if (graphicFormat.equals("PDF")) {
-                if (graphicFileName != null) {
-                    System.out.println("Creating PDF graphic: " + graphicFileName);
-                }
                 format = GraphicFormat.PDF;
-//            } else if (graphicFormat.equals("PS")) {
-//                if (graphicFileName != null) {
-//                    System.out.println("Creating PS graphic: " + graphicFileName);
-//                }
-//                g = new PSGraphics2D(stream, new Dimension(width, height));
-//            } else if (graphicFormat.equals("EMF")) {
-//                if (graphicFileName != null) {
-//                    System.out.println("Creating EMF graphic: " + graphicFileName);
-//                }
-//                g = new EMFGraphics2D(stream, new Dimension(width, height));
-//            } else if (graphicFormat.equals("SVG")) {
-//                if (graphicFileName != null) {
-//                    System.out.println("Creating SVG graphic: " + graphicFileName);
-//                }
-//                g = new SVGGraphics2D(stream, new Dimension(width, height));
-//            } else if (graphicFormat.equals("SWF")) {
-//                if (graphicFileName != null) {
-//                    System.out.println("Creating SWF graphic: " + graphicFileName);
-//                }
-//                g = new SWFGraphics2D(stream, new Dimension(width, height));
+            } else if (graphicFormat.equals("SVG")) {
+                format = GraphicFormat.SVG;
             } else if (graphicFormat.equals("GIF")) {
-                if (graphicFileName != null) {
-                    System.out.println("Creating GIF graphic: " + graphicFileName);
-                }
                 format = GraphicFormat.GIF;
             } else if (graphicFormat.equals("PNG")) {
                 format = GraphicFormat.PNG;
@@ -201,17 +175,18 @@ public class FigTreeApplication extends MultiDocApplication {
                 throw new RuntimeException("Unknown graphic format");
             }
 
-            JComponent comp = treeViewer.getContentPane();
-            BufferedImage bi = new BufferedImage(width, height, BufferedImage.TYPE_INT_ARGB);
-            Graphics g = bi.createGraphics();
-            comp.paint(g);
-            g.dispose();
-            ImageIO.write(bi, format.getName(), stream);
+            if (graphicFileName != null) {
+                System.out.println("Creating " + graphicFormat + " graphic: " + graphicFileName);
+            }
+
+            FigTreeFrame.exportGraphics(format, treeViewer.getContentPane(), stream);
 
         } catch(ImportException ie) {
-            throw new RuntimeException("Error writing graphic file: " + ie);
+            throw new RuntimeException("Error writing graphic file: " + ie.getMessage());
         } catch(IOException ioe) {
-            throw new RuntimeException("Error writing graphic file: " + ioe);
+            throw new RuntimeException("Error writing graphic file: " + ioe.getMessage());
+        } catch (DocumentException de) {
+            throw new RuntimeException("Error writing graphic file: " + de.getMessage());
         }
 
     }
@@ -236,6 +211,12 @@ public class FigTreeApplication extends MultiDocApplication {
         centreLine("http://tree.bio.ed.ac.uk/", 60);
         centreLine("Uses the Java Evolutionary Biology 2 Library (JEBL2)", 60);
         centreLine("http://jebl2.googlecode.com/", 60);
+        centreLine("Uses the iText PDF Library", 60);
+        centreLine("http://itextpdf.com/", 60);
+        centreLine("Uses the Apache Batik Library", 60);
+        centreLine("http://xmlgraphics.apache.org/batik/", 60);
+        centreLine("Uses the JDOM XML Library", 60);
+        centreLine("http://www.jdom.org/", 60);
         centreLine("Thanks to Alexei Drummond, Joseph Heled, Philippe Lemey, ", 60);
         centreLine("Tulio de Oliveira, Oliver Pybus, Beth Shapiro & Marc Suchard", 60);
         System.out.println();
@@ -247,7 +228,7 @@ public class FigTreeApplication extends MultiDocApplication {
         System.out.println();
         System.out.println("  Example: figtree test.tree");
         System.out.println("  Example: figtree -graphic PDF test.tree test.pdf");
-        System.out.println("  Example: figtree -graphic GIF -width 320 -height 320 test.tree test.gif");
+        System.out.println("  Example: figtree -graphic PNG -width 320 -height 320 test.tree test.png");
         System.out.println();
     }
 
@@ -264,10 +245,10 @@ public class FigTreeApplication extends MultiDocApplication {
                 new Arguments.Option[] {
                         new Arguments.StringOption("graphic", new String[] {
                                 "PDF",
-                                // "SVG",
+                                "SVG",
                                 // "SWF", "PS", "EMF",
                                 "PNG",
-                                "GIF",
+                                // "GIF",
                                 "JPEG"
                         }, false, "produce a graphic with the given format"),
                         new Arguments.IntegerOption("width", "the width of the graphic in pixels"),
@@ -341,6 +322,7 @@ public class FigTreeApplication extends MultiDocApplication {
                 javax.swing.SwingUtilities.invokeAndWait(new Runnable() {
                     public void run() {
                         try {
+
                             // Only override the UI's necessary for ColorChooser and
                             // FileChooser:
                             Set includes = new HashSet();
@@ -352,23 +334,20 @@ public class FigTreeApplication extends MultiDocApplication {
                             includes.add("SplitPane");
                             includes.add("TitledBorder");
 
-                            try {
-                                QuaquaManager.setIncludedUIs(includes);
-                            } catch (java.lang.NoClassDefFoundError ncdfe) {
-                                // this is to protect against the figtree.jar being
-                                // run on Mac OS without Quaqua on the classpath
-                            }
+                            Class<?> qm = Class.forName("ch.randelshofer.quaqua.QuaquaManager");
+                            Method method = qm.getMethod("setIncludedUIs", Set.class);
+                            method.invoke(null, includes);
 
                             UIManager.setLookAndFeel(
                                     "ch.randelshofer.quaqua.QuaquaLookAndFeel"
                             );
 
                             lafLoaded = true;
-                        } catch (Exception e) {
+                        } catch (Exception ignored) {
                         }
                     }
                 });
-            } catch (Exception e) {
+            } catch (Exception ignored) {
             }
 
             UIManager.put("SystemFont", new Font("Lucida Grande", Font.PLAIN, 13));
@@ -405,7 +384,7 @@ public class FigTreeApplication extends MultiDocApplication {
             icon = new ImageIcon(url);
         }
 
-        final String nameString = "FigTree " + VERSION;
+        final String nameString = "FigTree";
         String titleString = "<html>" +
                 "<div style=\"font-family:'Helvetica Neue', Helvetica, Arial, 'Lucida Grande',sans-serif\">" +
                 "<p style=\"font-weight: 100; font-size: 36px\">FigTree</p>" +
@@ -418,9 +397,9 @@ public class FigTreeApplication extends MultiDocApplication {
                 "Institute of Evolutionary Biology, University of Edinburgh.<br>" +
                 "<a href=\"http://tree.bio.ed.ac.uk/\">http://tree.bio.ed.ac.uk/</a><br><br>" +
                 "Source code available from:<br>" +
-                "<a href=\"https://figtree.googlecode.com/\">http://figtree.googlecode.com/</a><br><br>" +
+                "<a href=\"https://github.com/rambaut/figtree\">http://github.com/rambaut/figtree/</a><br><br>" +
                 "Uses the Java Evolutionary Biology 2 Library (JEBL2)<br>" +
-                "<a href=\"https://jebl2.googlecode.com/\">http://jebl2.googlecode.com/</a><br><br>" +
+                "<a href=\"https://github.com/rambaut/jebl2/\">http://github.com/rambaut/jebl2/</a><br><br>" +
                 "Thanks to Alexei Drummond, Joseph Heled, Philippe Lemey, <br>Tulio de Oliveira, Oliver Pybus, Beth Shapiro & Marc Suchard</center>" +
                 "</div></html>";
 
