@@ -274,6 +274,10 @@ public class DefaultTreeViewer extends TreeViewer {
         return treePane.getSelectedTips();
     }
 
+    public Set<Taxon> getSelectedTaxa() {
+        return treePane.getSelectedTaxa();
+    }
+
     /**
      * Select taxa with a search string matching the currently displayed attribute
      * @param searchType
@@ -601,6 +605,11 @@ public class DefaultTreeViewer extends TreeViewer {
         treePane.removeTreeSelectionListener(treeSelectionListener);
     }
 
+    public TreePaneSelector.SelectionMode getSelectionMode() {
+        return treePaneSelector.getSelectionMode();
+    }
+
+
     public void setSelectionMode(TreePaneSelector.SelectionMode selectionMode) {
         TreePaneSelector.SelectionMode oldSelectionMode = treePaneSelector.getSelectionMode();
 
@@ -639,6 +648,10 @@ public class DefaultTreeViewer extends TreeViewer {
 //        nodeBarPainter.setupAttributes(trees);
     }
 
+    public void setTipShapePainter(NodeShapePainter tipShapePainter) {
+        treePane.setTipShapePainter(tipShapePainter);
+    }
+
     public void setNodeShapePainter(NodeShapePainter nodeShapePainter) {
         treePane.setNodeShapePainter(nodeShapePainter);
     }
